Orbitz Travel: Airline Tickets, Cheap Hotels, Car Rentals, Vacations & Cruises
Description: Book cheap airline tickets, hotel reservations, car rentals, vacations and travel deals on Orbitz. Get our cheapest airfare and hotel deals or a 110% back automatically with Orbitz Price Assurance.
Keywords: cheap airline tickets, cheap plane tickets, airline tickets, plane tickets, cheap tickets, cheap airfare, cheap hotels, cheap vacations, hotel reservations, car rentals, travel deals, flight deals, hotel deals, air travel, air tickets, air fares, airfare, travel

Join
My Account
Welcome

- Asiana Airlines
- Turkish Airlines
- Mobile Apps

Get rewarded instantly with Orbitz Rewards! Learn more
Sign in or
Join
BOOK TOGETHER AND SAVE UP TO $675 *
Flight only Hotel only Car only Activities Cruises
Flight + Hotel Flight + Car Hotel + Car Flight + Hotel + Car
Search by city, region, or airport Search by address
Where
Check-in Check-out
Room 1
Adult (18+)
Child (0-17)
Ages of children at time of trip (for pricing, discounts)
Child 1
Child 2
Child 3
Child 4
Child 5

Star rating
Additional options
Hotel name
I have a promo code

- ## Popular destinations

- #### Las Vegas

  Las Vegas hotels are a swirl of sequins, cocktails and Blackjack. Lucky for you, we’ve got your ticket to The Strip with our Las Vegas flights. From mega-resorts to hot nightclubs and world-class dining, it’s time to travel like the high roller you are.

- #### New York

  With endless shops, museums and landmarks, this massive metropolis couldn’t sleep if it tried. Well, if you wanted to, there’s a dizzying array of New York hotels to pick from. Your NYC adventure starts now with our New York flights.

- #### Orlando

  Grab your bags and make way for an unforgettable stay at one of the many Orlando hotels. Add endless sunshine and roller coaster thrills for the trip of a lifetime. This theme park paradise closer than ever with our great deals on Orlando flights.

- #### Los Angeles

  A stay at Los Angeles hotels means luxe perks, celeb watching and laid-back beachy vibes. Surf in Santa Monica. Cause a ruckus on the Sunset Strip. Shop till you drop on Rodeo Drive. Whatever you do, get there with our Los Angeles flights.

- #### Chicago

  Jet off on our Chicago flights to the city that’s second to none. This urban escape is an oasis of lakeside beaches and enviable architecture—and it’s ripe for a visit from one of our Chicago hotels. It’s time to taste the best of the Midwest.

- #### We think hotel deals are a given

  We don’t stop at hotel deals and cheap tickets, we bring your vacation fantasies to life—and we have the tools to make it happen.

  We are your travel champions
  When it comes to airline tickets and hotel deals, we’ll do what it takes to help you make the most of your vacation. For one, you’ll never, ever pay an Orbitz booking fee on airline tickets for single-carrier flights that originate from the U.S., Canada, Mexico and the Caribbean. You heard right—absolutely none. Book those plane tickets with reckless abandon!

  We’ll help you Take Vacation Back
  Plans change, and that’s perfectly fine by us. After all, vacation is a state of mind, and the last thing you should be doing is worrying about change or cancel fees. With us, your hotel reservations are flexible. If you need to change your plans, there are no Orbitz change or cancel fees.

  We’re your go-to travel gurus
  If there’s one thing we know, it’s travel. Our emails have the latest on airfare sales and hotel deals just for Orbitz travelers. But when you sign up, you’ll get even more than sales on hotel reservations and cheap tickets for airfare, we’ll send you exclusive promo codes and important info about flight changes that might impact your trip.

  We’re with you, anywhere
  Travel is all about getting there. We’ve got the best apps for iPhone, iPad and Android so you can book plane tickets, rent cars, and make hotel reservations on the go.

  # Travel, Airline Tickets and Hotel Deals

### Go

- California
- Caribbean
- Florida
- Hawaii
- Las Vegas
- Mexico
- Atlantic City
- Cancun
- Daytona Beach
- Times Square
- See more

### Stay

- Disney®
- Hyatt Hotels
- Intercontinental
- Marriott Hotels
- MGM Las Vegas
- Universal Orlando®
- Atlantis
- ARIA Las Vegas
- Disney World®
- Disneyland®
- See more

### Play

- All-inclusive
- Beach resorts
- Gay travel
- Hotel deals
- Mobile apps
- Travel deals
- Casino hotels
- Eco-friendly
- Golf resorts
- Last-minute
- See more

## Hot hotel deals

From $29

### Treasure Island-TI

3.9 / 5 3509 reviews

Las Vegas, Nevada

TI Palooza! Cabana Credit, Mystere Savings & More

From $159

### The Line

4.1 / 5 95 reviews

Los Angeles, California

Fall on sale - Save 20% on your stay

From $99

### Universal's Cabana Bay Beach Resort

4.1 / 5 59 reviews

Orlando, Florida

From $193

### Warwick Hotel New York

4.3 / 5 520 reviews

New York, New York

Suite Sale - Save 10% on suites, 3 night minimum!

From $156

### St James' Court, A Taj Hotel, London

4.2 / 5 13 reviews

London, United Kingdom

From $239

### Majestic Elegance Punta Cana - All Inclusive

4.1 / 5 452 reviews

Punta Cana, Dominican Republic

## Top hotel destinations

Hotels in New York | Hotels in San Juan | Hotels in Paris | Hotels in Dallas | Hotels in Orange County | Hotels in Rome | Hotels in Boston | Hotels in Las Vegas | Hotels in Chicago | Hotels in Dubai | Hotels in Ft. Lauderdale | Hotels in Houston | Hotels in Myrtle Beach | Hotels in Jamaica | Hotels in Maui | Hotels in Melbourne | Hotels in Oahu | Hotels in Orlando | Hotels in Philadelphia | Hotels in Riviera Maya | Hotels in New Orleans

## Top flight destinations

Hawaii Flights | Florida Flights | London Flights | Puerto Rico Flights | Cancun Flights | Miami Flights | Costa Rica Flights | India Flights | Italy Flights | Mexico Flights | Paris Flights | Ireland Flights | Australia Flights | San Diego Flights | San Francisco Flights

*Savings based on Flight + Hotel vacation package bookings of 5 or more nights with individual calculable components on www.orbitz.com from January 1, 2014 through June 30, 2014, as compared to price of the same components booked separately. Savings will vary based on origin/destination, length of trip, stay dates, and selected travel supplier(s). Savings not available on all packages.